==> jc-1.4.0.tar.gz: javax/swing/text/TabSet.h <==
// public class javax.swing.text.TabSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 61f79014dfd25699 javax_swing_text_TabSet

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_TabSet_H_
#define _JC_javax_swing_text_TabSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_TabStop$object;

// Typedefs
typedef struct _jc_javax_swing_text_TabSet$sub_refs	_jc_javax_swing_text_TabSet$sub_refs;
typedef struct _jc_javax_swing_text_TabSet$sub_nonrefs	_jc_javax_swing_text_TabSet$sub_nonrefs;
typedef struct _jc_javax_swing_text_TabSet$refs	_jc_javax_swing_text_TabSet$refs;
typedef struct _jc_javax_swing_text_TabSet$nonrefs	_jc_javax_swing_text_TabSet$nonrefs;
typedef struct _jc_javax_swing_text_TabSet$object	_jc_javax_swing_text_TabSet$object;

typedef const struct _jc_javax_swing_text_TabSet$vmethods	_jc_javax_swing_text_TabSet$vmethods;
typedef const struct _jc_javax_swing_text_TabSet$vtable	_jc_javax_swing_text_TabSet$vtable;
typedef const struct _jc_javax_swing_text_TabSet$vtype	_jc_javax_swing_text_TabSet$vtype;

// Constructors
extern void _jc_javax_swing_text_TabSet$method$_init$df5953b55088272c(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_javax_swing_text_TabStop$object *_jc_javax_swing_text_TabSet$method$getTab$9e52bcd6aa70e097(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jint);
extern struct _jc_javax_swing_text_TabStop$object *_jc_javax_swing_text_TabSet$method$getTabAfter$eb430b570c3ba241(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jfloat);
extern jint _jc_javax_swing_text_TabSet$method$getTabCount$064dcb793b0885ed(_jc_env *, struct _jc_javax_swing_text_TabSet$object *);
extern jint _jc_javax_swing_text_TabSet$method$getTabIndex$61f61977222caf92(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, struct _jc_javax_swing_text_TabStop$object *);
extern jint _jc_javax_swing_text_TabSet$method$getTabIndexAfter$277129f7b1d3630c(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jfloat);
extern struct _jc_java_lang_String$object *_jc_javax_swing_text_TabSet$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_text_TabSet$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTab$9e52bcd6aa70e097;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTabAfter$eb430b570c3ba241;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTabCount$064dcb793b0885ed;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTabIndex$61f61977222caf92;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTabIndexAfter$277129f7b1d3630c;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_swing_text_TabSet$vmethods {
	struct _jc_javax_swing_text_TabStop$object	*(*getTab$9e52bcd6aa70e097)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jint);
	struct _jc_javax_swing_text_TabStop$object	*(*getTabAfter$eb430b570c3ba241)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jfloat);
	jint	(*getTabCount$064dcb793b0885ed)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *);
	jint	(*getTabIndex$61f61977222caf92)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, struct _jc_javax_swing_text_TabStop$object *);
	jint	(*getTabIndexAfter$277129f7b1d3630c)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jfloat);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *);
};

// Vtable
struct _jc_javax_swing_text_TabSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_TabSet$vmethods	javax_swing_text_TabSet;
};

// Vtype
struct _jc_javax_swing_text_TabSet$vtype {
	_jc_type			type;
	_jc_javax_swing_text_TabSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_TabSet$sub_refs {
	_jc_object_array	*tabs;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_TabSet$refs {
    _jc_javax_swing_text_TabSet$sub_refs	javax_swing_text_TabSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_TabSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_TabSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_TabSet$sub_nonrefs	javax_swing_text_TabSet;
};

// Object instance structure
struct _jc_javax_swing_text_TabSet$object {
	_jc_javax_swing_text_TabSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_TabSet$vtype	*vtype;
	_jc_javax_swing_text_TabSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_TabSet$vtype _jc_javax_swing_text_TabSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_TabSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_TabSet$class_object;

#endif	/* _JC_javax_swing_text_TabSet_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/TabSet.h <==
// public class javax.swing.text.TabSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 61f79014dfd25699 javax_swing_text_TabSet

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_TabSet_H_
#define _JC_javax_swing_text_TabSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_TabStop$object;

// Typedefs
typedef struct _jc_javax_swing_text_TabSet$sub_refs	_jc_javax_swing_text_TabSet$sub_refs;
typedef struct _jc_javax_swing_text_TabSet$sub_nonrefs	_jc_javax_swing_text_TabSet$sub_nonrefs;
typedef struct _jc_javax_swing_text_TabSet$refs	_jc_javax_swing_text_TabSet$refs;
typedef struct _jc_javax_swing_text_TabSet$nonrefs	_jc_javax_swing_text_TabSet$nonrefs;
typedef struct _jc_javax_swing_text_TabSet$object	_jc_javax_swing_text_TabSet$object;

typedef const struct _jc_javax_swing_text_TabSet$vmethods	_jc_javax_swing_text_TabSet$vmethods;
typedef const struct _jc_javax_swing_text_TabSet$vtable	_jc_javax_swing_text_TabSet$vtable;
typedef const struct _jc_javax_swing_text_TabSet$vtype	_jc_javax_swing_text_TabSet$vtype;

// Constructors
extern void _jc_javax_swing_text_TabSet$method$_init$df5953b55088272c(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_text_TabStop$object *_jc_javax_swing_text_TabSet$method$getTab$9e52bcd6aa70e097(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_text_TabStop$object *_jc_javax_swing_text_TabSet$method$getTabAfter$eb430b570c3ba241(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jfloat) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_TabSet$method$getTabCount$064dcb793b0885ed(_jc_env *, struct _jc_javax_swing_text_TabSet$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_TabSet$method$getTabIndex$61f61977222caf92(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_TabSet$method$getTabIndexAfter$277129f7b1d3630c(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jfloat) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_text_TabSet$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_text_TabSet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTab$9e52bcd6aa70e097;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTabAfter$eb430b570c3ba241;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTabCount$064dcb793b0885ed;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTabIndex$61f61977222caf92;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$getTabIndexAfter$277129f7b1d3630c;
extern _jc_method _jc_javax_swing_text_TabSet$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_swing_text_TabSet$vmethods {
	struct _jc_javax_swing_text_TabStop$object	*(*getTab$9e52bcd6aa70e097)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jint) _JC_JCNI_ATTR;
	struct _jc_javax_swing_text_TabStop$object	*(*getTabAfter$eb430b570c3ba241)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jfloat) _JC_JCNI_ATTR;
	jint	(*getTabCount$064dcb793b0885ed)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *) _JC_JCNI_ATTR;
	jint	(*getTabIndex$61f61977222caf92)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
	jint	(*getTabIndexAfter$277129f7b1d3630c)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *, jfloat) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_text_TabSet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_TabSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_TabSet$vmethods	javax_swing_text_TabSet;
};

// Vtype
struct _jc_javax_swing_text_TabSet$vtype {
	_jc_type			type;
	_jc_javax_swing_text_TabSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_TabSet$sub_refs {
	_jc_object_array	*tabs;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_TabSet$refs {
    _jc_javax_swing_text_TabSet$sub_refs	javax_swing_text_TabSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_TabSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_TabSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_TabSet$sub_nonrefs	javax_swing_text_TabSet;
};

// Object instance structure
struct _jc_javax_swing_text_TabSet$object {
	_jc_javax_swing_text_TabSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_TabSet$vtype	*vtype;
	_jc_javax_swing_text_TabSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_TabSet$vtype _jc_javax_swing_text_TabSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_TabSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_TabSet$class_object;

#endif	/* _JC_javax_swing_text_TabSet_H_ */
